==> IMDBTraktSyncer-1.9.3-py3-none-any.whl: IMDBTraktSyncer/checkVersion.py <==
import xml.etree.ElementTree as ET
import urllib.request
import subprocess

def get_installed_version():
    try:
        result = subprocess.run(['pip', 'show', 'imdbtraktsyncer'], capture_output=True, text=True, check=True)
        for line in result.stdout.splitlines():
            if line.startswith("Version:"):
                return line.split()[1]
    except subprocess.CalledProcessError as e:
        print(f"Error retrieving installed version: {e}")
        return None

def get_latest_version():
    try:
        with urllib.request.urlopen("https://pypi.org/rss/project/imdbtraktsyncer/releases.xml") as response:
            xml_data = response.read()
        root = ET.fromstring(xml_data)
        for item in root.findall('./channel/item'):
            title = item.find('title').text
            if title:
                return title
    except Exception as e:
        print(f"Error retrieving latest version: {e}")
        return None

def compare_versions(installed, latest):
    def parse_version(v):
        return tuple(map(int, v.split('.')))
    
    return parse_version(installed) < parse_version(latest)

def checkVersion():
    installed_version = get_installed_version()
    if not installed_version:
        print("IMDBTraktSyncer is not installed.")
        return

    latest_version = get_latest_version()
    if not latest_version:
        print("Could not retrieve the latest version.")
        return

    if compare_versions(installed_version, latest_version):
        print(f"A new version of IMDBTraktSyncer is available: {latest_version} (installed: {installed_version}).")
        print("To update use: python -m pip install IMDBTraktSyncer --upgrade")
        print("Documentation: https://github.com/RileyXX/IMDB-Trakt-Syncer")
    # else:
        # print(f"IMDBTraktSyncer is up to date (installed: {installed_version})")

checkVersion()

==> IMDBTraktSyncer-3.0.1-py3-none-any.whl: IMDBTraktSyncer/checkVersion.py <==
import xml.etree.ElementTree as ET
import urllib.request
import subprocess

def get_installed_version():
    try:
        result = subprocess.run(['python', '-m', 'pip', 'show', 'imdbtraktsyncer'], capture_output=True, text=True, check=True)
        for line in result.stdout.splitlines():
            if line.startswith("Version:"):
                return line.split()[1]
    except subprocess.CalledProcessError as e:
        print(f"Error retrieving installed version: {e}")
        return None

def get_latest_version():
    try:
        with urllib.request.urlopen("https://pypi.org/rss/project/imdbtraktsyncer/releases.xml") as response:
            xml_data = response.read()
        root = ET.fromstring(xml_data)
        for item in root.findall('./channel/item'):
            title = item.find('title').text
            if title:
                return title
    except Exception as e:
        print(f"Error retrieving latest version: {e}")
        return None

def compare_versions(installed, latest):
    def parse_version(v):
        return tuple(map(int, v.split('.')))
    
    return parse_version(installed) < parse_version(latest)

def checkVersion():
    installed_version = get_installed_version()
    if not installed_version:
        print("IMDBTraktSyncer is not installed.")
        return

    latest_version = get_latest_version()
    if not latest_version:
        print("Could not retrieve the latest version.")
        return

    if compare_versions(installed_version, latest_version):
        print(f"A new version of IMDBTraktSyncer is available: {latest_version} (installed: {installed_version}).")
        print("To update use: python -m pip install IMDBTraktSyncer --upgrade")
        print("Documentation: https://github.com/RileyXX/IMDB-Trakt-Syncer/releases")
    # else:
        # print(f"IMDBTraktSyncer is up to date (installed: {installed_version})")

checkVersion()
